@@ -1,7 +1,7 @@
 """
 Type annotations for elastictranscoder service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/literals/)
 
 Usage::
 
@@ -30,6 +30,7 @@ __all__ = (
     "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
@@ -157,6 +158,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -358,3 +360,13 @@ PaginatorName = Literal[
     "list_jobs_by_pipeline", "list_jobs_by_status", "list_pipelines", "list_presets"
 ]
 WaiterName = Literal["job_complete"]
+RegionName = Literal[
+    "ap-northeast-1",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "eu-west-1",
+    "us-east-1",
+    "us-west-1",
+    "us-west-2",
+]
