@@ -1,7 +1,7 @@
 """
 Type annotations for elastictranscoder service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/type_defs/)
 
 Usage::
 
@@ -50,12 +50,16 @@ __all__ = (
     "JobOutputTypeDef",
     "JobTypeDef",
     "JobWatermarkTypeDef",
+    "ListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef",
     "ListJobsByPipelineRequestRequestTypeDef",
     "ListJobsByPipelineResponseTypeDef",
+    "ListJobsByStatusRequestListJobsByStatusPaginateTypeDef",
     "ListJobsByStatusRequestRequestTypeDef",
     "ListJobsByStatusResponseTypeDef",
+    "ListPipelinesRequestListPipelinesPaginateTypeDef",
     "ListPipelinesRequestRequestTypeDef",
     "ListPipelinesResponseTypeDef",
+    "ListPresetsRequestListPresetsPaginateTypeDef",
     "ListPresetsRequestRequestTypeDef",
     "ListPresetsResponseTypeDef",
     "NotificationsTypeDef",
@@ -67,6 +71,7 @@ __all__ = (
     "PlaylistTypeDef",
     "PresetTypeDef",
     "PresetWatermarkTypeDef",
+    "ReadJobRequestJobCompleteWaitTypeDef",
     "ReadJobRequestRequestTypeDef",
     "ReadJobResponseTypeDef",
     "ReadPipelineRequestRequestTypeDef",
@@ -395,6 +400,15 @@ JobWatermarkTypeDef = TypedDict(
     },
 )
 
+ListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef = TypedDict(
+    "ListJobsByPipelineRequestListJobsByPipelinePaginateTypeDef",
+    {
+        "PipelineId": str,
+        "Ascending": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListJobsByPipelineRequestRequestTypeDef = TypedDict(
     "ListJobsByPipelineRequestRequestTypeDef",
     {
@@ -413,6 +427,15 @@ ListJobsByPipelineResponseTypeDef = TypedDict(
     },
 )
 
+ListJobsByStatusRequestListJobsByStatusPaginateTypeDef = TypedDict(
+    "ListJobsByStatusRequestListJobsByStatusPaginateTypeDef",
+    {
+        "Status": str,
+        "Ascending": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListJobsByStatusRequestRequestTypeDef = TypedDict(
     "ListJobsByStatusRequestRequestTypeDef",
     {
@@ -431,6 +454,14 @@ ListJobsByStatusResponseTypeDef = TypedDict(
     },
 )
 
+ListPipelinesRequestListPipelinesPaginateTypeDef = TypedDict(
+    "ListPipelinesRequestListPipelinesPaginateTypeDef",
+    {
+        "Ascending": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPipelinesRequestRequestTypeDef = TypedDict(
     "ListPipelinesRequestRequestTypeDef",
     {
@@ -448,6 +479,14 @@ ListPipelinesResponseTypeDef = TypedDict(
     },
 )
 
+ListPresetsRequestListPresetsPaginateTypeDef = TypedDict(
+    "ListPresetsRequestListPresetsPaginateTypeDef",
+    {
+        "Ascending": NotRequired[str],
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListPresetsRequestRequestTypeDef = TypedDict(
     "ListPresetsRequestRequestTypeDef",
     {
@@ -575,6 +614,14 @@ PresetWatermarkTypeDef = TypedDict(
     },
 )
 
+ReadJobRequestJobCompleteWaitTypeDef = TypedDict(
+    "ReadJobRequestJobCompleteWaitTypeDef",
+    {
+        "Id": str,
+        "WaiterConfig": NotRequired["WaiterConfigTypeDef"],
+    },
+)
+
 ReadJobRequestRequestTypeDef = TypedDict(
     "ReadJobRequestRequestTypeDef",
     {
